<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="45"/>
        <source>AAC Plugin</source>
        <translation>AAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="47"/>
        <source>AAC Files</source>
        <translation>AAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="87"/>
        <source>About AAC Audio Plugin</source>
        <translation>關於 AAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="88"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>Qmmp AAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
